@@ -12,36 +12,35 @@ from typing import Any, Callable, Dict, Iterable, List, Literal, TypedDict, Unio
 # Eventually we should move to this. At present however, isinstance() cannot handle these types
 # see: https://github.com/python/mypy/issues/3325
 # SqlText = NewType("SqlText", str)
-# TableName = NewType("TableName", str)
-# ColName = NewType("ColName", str)
+# Identifier = NewType("Identifier", str)
 
 SqlText = str
-TableName = str
-ColName = str
+Identifier = str
 
-Intermediate = Union[SqlText, ColName, TableName, Iterable["Intermediate"]]
+# Compiler Intermediate representation
+Intermediate = Union[SqlText, Identifier, Iterable["Intermediate"]]
 
 
 def isTableName(obj: Any):
-    return isinstance(obj, TableName)
+    return isinstance(obj, Identifier)
 
 
 def isColName(obj: Any):
-    return isinstance(obj, ColName)
+    return isinstance(obj, Identifier)
 
 
 # Sanitizer
 SanitizerT = Callable[[SqlText], SqlText]
 
 
-ColNameList = List[ColName]
+ColNameList = List[Identifier]
 
 
 def isColNameList(obj: Any):
     return isinstance(obj, list)
 
 
-TableNameList = List[TableName]
+TableNameList = List[Identifier]
 
 
 def isTableNameList(obj: Any):
@@ -50,7 +49,7 @@ def isTableNameList(obj: Any):
 
 # Select Clause
 
-SelectClause = Union[ColName, ColNameList]
+SelectClause = Union[Identifier, ColNameList]
 
 # From Clause
 
@@ -75,7 +74,7 @@ def isJoin(obj: Any):
     return isinstance(obj, dict) and "Join" in obj
 
 
-FromClauseSub = Union["SubQuery", TableName, JoinClause]
+FromClauseSub = Union["SubQuery", Identifier, JoinClause]
 FromClause = Union[FromClauseSub, List[FromClauseSub]]
 
 # Where Clause
@@ -159,7 +158,7 @@ def isSelectStatement(obj: Any):
 
 
 class SubQuery(TypedDict):
-    Alias: TableName
+    Alias: Identifier
     Query: SelectStatement
 
 
@@ -169,11 +168,11 @@ def isSubQuery(obj: Any):
 
 # Insert statement
 
-ValueMap = Dict[ColName, Any]
+ValueMap = Dict[Identifier, Any]
 
 # TODO: find better name
 class ValueClause(TypedDict):
-    Table: TableName
+    Table: Identifier
     Data: ValueMap
 
 
@@ -197,6 +196,22 @@ def isUpdateStatement(obj: Any):
     return isinstance(obj, dict) and "Update" in obj
 
 
+# Delete Statement
+
+
+class DeleteClause(TypedDict):
+    Table: Identifier
+
+
+class DeleteStatement(TypedDict, total=False):
+    Delete: DeleteClause
+    Where: WhereClause
+
+
+def isDeleteStatement(obj: Any):
+    return isinstance(obj, dict) and "Delete" in obj
+
+
 # Statement
 
-Statement = Union[SelectStatement, InsertStatement, UpdateStatement]
+Statement = Union[SelectStatement, InsertStatement, UpdateStatement, DeleteStatement]
